@@ -7,8 +7,7 @@ from trytond.pool import PoolMeta, Pool
 __all__ = ['Sale', 'SaleLine']
 
 
-class Sale:
-    __metaclass__ = PoolMeta
+class Sale(metaclass=PoolMeta):
     __name__ = 'sale.sale'
     price_list = fields.Many2One('product.price_list', 'Price List',
         help="Use to compute the unit price of lines.",
@@ -40,19 +39,16 @@ class Sale:
             self.price_list = config.sale_price_list
 
 
-class SaleLine:
-    __metaclass__ = PoolMeta
+class SaleLine(metaclass=PoolMeta):
     __name__ = 'sale.line'
 
     @classmethod
     def __setup__(cls):
         super(SaleLine, cls).__setup__()
-        cls.quantity.on_change.add('_parent_sale.price_list')
-        cls.unit.on_change.add('_parent_sale.price_list')
-        cls.product.on_change.add('_parent_sale.price_list')
         cls.product.context['price_list'] = Eval(
             '_parent_sale', {}).get('price_list')
 
+    @fields.depends('sale', '_parent_sale.price_list')
     def _get_context_sale_price(self):
         context = super(SaleLine, self)._get_context_sale_price()
         if self.sale and getattr(self.sale, 'price_list', None):
